.. _apiref:

===============
 API Reference
===============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 1

    cyanide
    cyanide.app
    cyanide.bin.cyanide
    cyanide.bin.vagrant
    cyanide.suite
    cyanide.suites.default
    cyanide.tasks
    cyanide.vagrant
    cyanide.templates
    cyanide.data
    cyanide.fbi
    cyanide.compat
